pub enum IndexRefreshPolicy {
WhenRun,
WhenUsed,
EachFrame,
Manual,
}Expand description
Variants
WhenRun
Refresh the index whenever a system with an Index argument is run.
This is a good default for most use cases.
WhenUsed
Refresh the index the first time lookup is called in each system.
Compared to WhenRun, this requires an extra check in each lookup
to see if the index needs to be refreshed or not, but saves the overhead of an entire refresh
when lookup is never called.
EachFrame
Refresh the index once during the First
Schedule.
To refresh during a different schedule, you can manually add the refresh_index_system.
Manual